# -*- coding: utf-8 -*-

import sys

class ImageFile:
    """ファームウェアイメージファイルを扱うクラス"""
    
    chunkSize = 64*1024 # 64KB
    
    def __init__(self, filename):
        """コンストラクタ。ファームウェアイメージファイルを読み込む"""
        with open(filename, "rb") as imgfile:
            # イメージファイルであるかどうか確認
            data = imgfile.read(16)
            if not data.startswith(b'REV-', 0x8):
                raise ValueError('File is not imagefile.')
        
            # イメージファイルだったので、バージョン番号を取得
            self._major = data[0xc]
            self._minor = data[0xd]
            self._revision = data[0xe]
            self._build = data[0xf]
            
            # 改めてファイルを全部読む
            imgfile.seek(0)
            self._data = imgfile.read()
            self._maxchunk = int(len(self._data)/self.chunkSize)
            # ファイルサイズがちょうど64KBの倍数の時は、maxchunkを-1する(例: 64KBの時は商は1になるがmaxchunkは0)
            if len(self._data) % self.chunkSize == 0:
                self._maxchunk -= 1
    
    def getChunk(self, index):
        if index < 0 or index > self._maxchunk:
            raise ValueError()
        
        if (index == self._maxchunk):
            # 最後のチャンク。データの最後まで
            return self._data[index * self.chunkSize :]
        else:
            # 最後以外のチャンク。
            return self._data[index * self.chunkSize : (index+1)*self.chunkSize]

    def getMaxChunkIndex(self):
        return self._maxchunk

    def getSize(self):
        return len(self._data)

def testImageFile():
    try:
        imageFile = ImageFile(sys.argv[1])
    except Exception as ex:
        print(type(ex))
        print(ex)

if __name__ == "__main__":
    testImageFile()
